@@ -12,8 +12,11 @@
 #ifndef _UTF8_H_
 #define _UTF8_H_
 
-unsigned int utf8toint( char *s );
-unsigned int utf8toint( char **s );
-char *int2utf8( unsigned int );
+namespace SFST {
 
+unsigned int utf8toint(char *s);
+unsigned int utf8toint(char **s);
+char *int2utf8(unsigned int);
+
+} // namespace SFST
 #endif
